#
# spec file for package gdk-pixbuf
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# When updating the binary version, do not forget to also update baselibs.conf
%define gdk_pixbuf_binary_version 2.10.0

Name:           gdk-pixbuf
Version:        2.22.1
Release:        7.1
Summary:        An image loading library
License:        LGPL-2.1+
Group:          System/Libraries
Source:         %{name}-%{version}.tar.bz2
Source1:        macros.gdk-pixbuf
Source2:        README.SUSE
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM gdk-pixbuf-add-gir_PACKAGES.patch bgo#635364 dimstar@opensuse.org -- Add gir_PACKAGES. This helps vapigen 0.12 to add proper package information, needed to bind .vapi and .gir files, in case both are installed.
Patch0:         gdk-pixbuf-add-gir_PACKAGES.patch
# PATCH-FIX-UPSTREAM gdk-pixbuf-CVE-2012-2370.patch bnc#762735 CVE-2012-2370 vuntz@opensuse.org -- ix integer overflow in XBM file loader
Patch1:         gdk-pixbuf-CVE-2012-2370.patch
# Needed for patch0
BuildRequires:  gnome-common
BuildRequires:  libjasper-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(x11)

%description
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

%package -n libgdk_pixbuf-2_0-0
Summary:        An image loading library
Group:          System/Libraries
# Provide %{name} to make the lang package installable
Provides:       %{name} = %{version}
Requires(post): gdk-pixbuf-query-loaders
Recommends:     %{name}-lang = %{version}
Conflicts:      gtk2 < 2.21.3

%description  -n libgdk_pixbuf-2_0-0
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

%package query-loaders
Summary:        An image loading library - Utility to create loaders cache
Group:          System/Libraries

%description query-loaders
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

This package contains the utility to create the cache file needed for
loadable modules.

%package devel
Summary:        An image loading library - Development Files
Group:          Development/Languages/C and C++
Requires:       libgdk_pixbuf-2_0-0 = %{version}

%description devel
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

This package contains development files for gdk-pixbuf.

%lang_package
%prep
%setup -q
%if "%_lib" == "lib64"
cp -a %{S:2} .
%endif
%patch0 -p1
%patch1 -p1

%build
# Needed for patch0
NOCONFIGURE=1 gnome-autogen.sh
%configure \
        --disable-static \
        --enable-introspection \
        --with-libjasper
%{__make} %{?_smp_mflags}

%install
%makeinstall
find %{buildroot}%{_libdir} -name '*.la' -delete -print
%find_lang %{name}
touch %{buildroot}%{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders.cache
%if "%_lib" == "lib64"
  mv %{buildroot}%{_bindir}/gdk-pixbuf-query-loaders %{buildroot}%{_bindir}/gdk-pixbuf-query-loaders-64
  mv %{buildroot}%{_mandir}/man1/gdk-pixbuf-query-loaders.1 %{buildroot}%{_mandir}/man1/gdk-pixbuf-query-loaders-64.1
%endif
# Install rpm macros
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cp %{S:1} %{buildroot}%{_sysconfdir}/rpm

###########################################################################
# Note: when updating scriptlets, don't forget to also update baselibs.conf
###########################################################################

# Convenient %define for the scriplets
%if "%_lib" == "lib64"
%define _gdk_pixbuf_query_loaders %{_bindir}/gdk-pixbuf-query-loaders-64
%else
%define _gdk_pixbuf_query_loaders %{_bindir}/gdk-pixbuf-query-loaders
%endif
%define _gdk_pixbuf_query_loaders_update_cache %{_gdk_pixbuf_query_loaders} --update-cache

%post -n libgdk_pixbuf-2_0-0
/sbin/ldconfig
%if 0
# In case libgdk_pixbuf-2_0-0 gets installed before gdk-pixbuf-query-loaders,
# we don't want to fail. So we make the call to gdk-pixbuf-query-loaders
# dependent on the existence of the binary. This is why we also have a %post
# for gdk-pixbuf-query-loaders.
%endif
if test -f %{_gdk_pixbuf_query_loaders}; then
  %{_gdk_pixbuf_query_loaders_update_cache}
fi

%post query-loaders
%if 0
# If we install gdk-pixbuf-query-loaders for the first time, then we should run
# it in case libgdk_pixbuf-2_0-0 was installed first (ie, if
# %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version} already exists) which
# means gdk-pixbuf-query-loaders couldn't run there.
%endif
if [ $1 == 1 ]; then
  test -d %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}
  if test $? -eq 0; then
    %{_gdk_pixbuf_query_loaders_update_cache}
  fi
fi

%if 0
# No need to call gdk-pixbuf-query-loaders in postun:
# - if it's an upgrade, it will have been called in post
# - if it's an uninstall, we don't care about this anymore
%endif

%postun -n libgdk_pixbuf-2_0-0 -p /sbin/ldconfig

%files -n libgdk_pixbuf-2_0-0
%defattr(-, root, root)
%doc AUTHORS COPYING NEWS README
%if "%_lib" == "lib64"
%doc README.SUSE
%endif
%{_libdir}/libgdk_pixbuf-2.0.so.0*
%{_libdir}/libgdk_pixbuf_xlib-2.0.so.0*
%dir %{_libdir}/gdk-pixbuf-2.0
%dir %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}
%dir %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders
%{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders/*.so
%ghost %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders.cache
%{_libdir}/girepository-1.0/GdkPixbuf-2.0.typelib

%files query-loaders
%defattr(-, root, root)
%{_bindir}/gdk-pixbuf-query-loaders*
%{_mandir}/man1/gdk-pixbuf-query-loaders*.1*

%files devel
%defattr(-, root, root)
%{_bindir}/gdk-pixbuf-csource
%{_mandir}/man1/gdk-pixbuf-csource.1*
%{_includedir}/gdk-pixbuf-2.0
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_datadir}/gir-1.0/GdkPixbuf-2.0.gir
%doc %{_datadir}/gtk-doc/html/gdk-pixbuf
%{_sysconfdir}/rpm/macros.gdk-pixbuf

%files lang -f %{name}.lang

%changelog
* Fri Jul 13 2012 vuntz@opensuse.org
- Add gdk-pixbuf-CVE-2012-2370.patch: fix integer overflow in XBM
  file loader. Fix bnc#762735, CVE-2012-2370.
* Wed Dec 29 2010 dimstar@opensuse.org
- Add gdk-pixbuf-add-gir_PACKAGES.patch: vapigen 0.12 parses the
  .gir and the .vapi file, complaining about duplicate definitions.
  The error is seen in packages building against gdk-pixbuf and
  using vala-unstable to create own vala bindings.
- Add gnome-common BuildRequires, because the patch touches
  Makefile.am, and call to gnome-autogen.sh in the build section.
* Sat Nov  6 2010 dimstar@opensuse.org
- Update to version 2.22.1:
  + Make GdkPixbuf implement the GIcon interface
  + Fix loader.cache detection on Windows
  + Updated translations.
* Wed Oct 13 2010 vuntz@opensuse.org
- Put comments that are in the scriptlets area of the spec file in
  "%%if 0" statement: if we don't do that, they actually end up in
  the scriplets and can even make them fail if the scriptlets were
  just "-p /sbin/ldconfig".
* Tue Oct 12 2010 vuntz@opensuse.org
- Remove gdk-pixbuf-query-loaders Requires(postun) in
  libgdk_pixbuf-2_0-0: it's not needed.
- Add missing Requires for gdk-pixbuf-query-loaders to
  libgdk_pixbuf-2_0-0 in baselibs.conf.
- Update baselibs.conf to remove assumption in the scriptlets of
  the generated packages that they are 32bit packages.
- Use <prefix> in baselibs.conf since we use full paths there, and
  this is needed for x86 packages that put files in
  /emul/ia32-linux.
* Tue Sep 21 2010 vuntz@opensuse.org
- Update to version 2.22.0:
  + Fix a problem with mime type detection
  + Win32: Fix linking on x64
  + Drop gobject-introspection requirement to 0.9.3
  + Updated translations.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update the %%post scriptlet to not fail if
  gdk-pixbuf-query-loaders is not installed. Also make it easier to
  read by using a %%define to use the right binary for
  gdk-pixbuf-query-loaders.
* Fri Sep 10 2010 dimstar@opensuse.org
- Update to version 2.21.7:
  + bgo#624712: Fix linking when libpng loader is builtin
  + bgo#604284: Improve the pixbuf loader docs
  + bgo#622940: Fix compat issues wrt to single includes
  + Win32: Link directly to GDI+
  + Require gobject-introspection 0.9.5
  + Updated translations.
* Fri Jul 23 2010 vuntz@opensuse.org
- Update to version 2.21.6:
  + Drop aliasing hacks, use -Bsymbolic-functions
  + Support NOCONFIGURE in autogen.sh
  + Check for different versions of libpng
* Wed Jul 21 2010 vuntz@opensuse.org
- Improve summaries and descriptions.
- Change gobject-introspection-devel and libpng-devel BuildRequires
  to pkgconfig(gobject-introspection-1.0) and pkgconfig(libpng).
- Add libjasper-devel, pkgconfig(x11) BuildRequires, and explicit
  libjpeg-devel.
- Add baselibs.conf, and rename gdk-pixbuf-query-loaders on 64
  bits.
- Make libgdk_pixbuf-2_0-0 provide gdk-pixbuf to make the lang
  package installable.
- Add Recommends for the lang package to libgdk_pixbuf-2_0-0.
- Move conflicts with gtk2 < 2.21 to libgdk_pixbuf-2_0-0.
- Stop renaming gdk-pixbuf-query-loaders to
  gdk-pixbuf-query-loaders-2.0: they're no issue with parallel
  instability since there's no other such tool.
- Touch %%{_libdir}/gdk-pixbuf-2.0/2.10.0/loaders.cache and make it
  a ghost file.
- Pass --disable-static and --with-libjasper to configure.
- Enable parallel build.
- Move gtk-doc documentation and gdk-pixbuf-csource to devel
  subpackage.
- Add a macros.gdk-pixbuf file containing useful macros for
  packages that ship gdk-pixbuf loaders.
* Tue Jul  6 2010 dimstar@opensuse.org
- Initial package of gdk-pixbuf, which has been split out of gtk2
  main package. For this reason it conflicts with gtk < 2.21
- Changes from version 2.21.5:
  + Bring back deprecated API
  + Allow including individual headers again
- Changes from version 2.21.4:
  + Drop -2.0 suffix on gdk-pixbuf-csource and
    gdk-pixbuf-query-loaders
  + Include gdk-pixbuf-xlib again
  + Add pixbuf tests from the GTK+ tree
  + Add binary version and module dir as variables in the .pc file
  + Add a boxed type for GdkPixbufFormat
- Changes from version 2.21.3, since GTK+ 2.21.2:
  + gdk-pixbuf has been turned back into a standalone library.
  + The default location for loaders has been changed to
    $libdir/gdk-pixbuf-2.0/2.10.0/loaders
  + The default location for the module file has been changed to
    $libdir/gdk-pixbuf-2.0/2.10.0/loaders.cache
    and gdk-pixbuf-query-loaders-2.0 will update that file when
    given the --update-cache option.
